#
# spec file for package liberasurecode
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libsoname liberasurecode1
Name:           liberasurecode
Version:        1.5.0
Release:        bp153.1.18
Summary:        Erasure Code API library with pluggable Erasure Code backends
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://github.com/openstack/liberasurecode
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
Source0:        %{name}-%{version}.tar.gz

%description
liberasurecode is an Erasure Code API library written in C with
pluggable Erasure Code backends.

%package -n %{libsoname}
Summary:        Erasure Code API library with pluggable Erasure Code backends
Group:          System/Libraries

%description -n %{libsoname}
liberasurecode is an Erasure Code API library written in C with
pluggable Erasure Code backends.

%package devel
Summary:        liberasurecode development files
Group:          Development/Libraries/C and C++
Requires:       %{libsoname} = %{version}

%description devel
Development files for the Unified Erasure Coding interface.

%prep
%setup -q

%build
./autogen.sh
%configure --disable-static --disable-mmi
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%check
make test

%post -n %{libsoname} -p /sbin/ldconfig

%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%doc ChangeLog README COPYING
%{_libdir}/libXorcode.so.*
%{_libdir}/liberasurecode.so.*
%{_libdir}/libnullcode.so.*
%{_libdir}/liberasurecode_rs_vand.so.*

%files devel
%{_includedir}/liberasurecode
%{_includedir}/config_liberasurecode.h
%{_includedir}/erasurecode*.h
%{_libdir}/libXorcode.la
%{_libdir}/libXorcode.so
%{_libdir}/liberasurecode.la
%{_libdir}/liberasurecode.so
%{_libdir}/libnullcode.la
%{_libdir}/libnullcode.so
%{_libdir}/liberasurecode_rs_vand.la
%{_libdir}/liberasurecode_rs_vand.so
%{_libdir}/pkgconfig/erasurecode-1.pc

%changelog
* Tue Oct 24 2017 dmueller@suse.com
- update to 1.5.0:
  * Added support for Phazr.IO libphazr library
  * memory leak fixes
  * avoid Galois Field multiplication tables to be calculated repeatedly
- remove partial-disable-simd.patch: replaced by --disable-mmi
* Thu Jan 12 2017 jengelh@inai.de
- Update RPM group and summaries (bsc#1041161)
* Wed Jan 11 2017 aplanas@suse.com
- Add partial-disable-simd.patch
  Some libraries like python-PyECLib fail in OBS during the tests.
  This can be because in OBS SSE2, SSE3 and other SIMD extensions are
  not properly addressed by QEMU.
  This patch remove some SIMD extensions, maintaining MMX+SSE for
  x86_64 systems.
- Add buildreuired for pkg-config
* Sat Jan  7 2017 dmueller@suse.com
- update to 1.4.0:
  . Added support for ISA-L Cauchy
  . Added get_version functionality to library
  . Fixed reconstruct to return an error when memory allocation failed
  . Fixed posix_memalign error handling
  . Fixed the internal version number. It was inadvertently skipped in 1.3.0.
  . Fixed error handling on gf_ivnert_matrix in isa-l backend
  . Added get_by_desc return value handling to get_fragment_size
  . Other minor fixes and updates
* Mon Oct 10 2016 dmueller@suse.com
- update to 1.2.0:
  . Add functionality to enable consumers to check which backends are
  present on a system
  . Fix segfault when fragment index is out of range
  . Add fragment metadata checksumming support
* Mon Feb 29 2016 dmueller@suse.com
- update to 1.1.0
  * Fix for a segfault related to Jerasure uninit() function that is being
  looked up by the jerasure EC backend (Issue#19)
  * Split helpers.h include for backward compatibility
  * Create header symlinks in std locations for backward compat (<= 1.0.8)
  * Eliminate erasurecode_stdinc.h dependency on log.h
  * Move fragment_header defn to main erasurecode header
  * doxygen documentation fixes
  * Minor bugfixes including removing offending MAJOR/MINOR version macros
  * Enforce upper limit 32 on the number of erasure coding fragments
  (#data + #chunks) < 32
  * Introduce 'liberasurecode_rs_vand', a native, software-based Reed-Soloman
  Vandermonde backend
  * Properly set W in the new internal RS backend.  Without this change, the
  fragment length passed up is incorrect.
  * Remove all GPLv3 m4 references for CPUID checks
  * Properly dedupe fragments in fragments_to_string() function
  * Prevent backends from reconstructing an index when it is not missing,
  ie, is available
  * Make ./configure to obey CFLAGS
  * Add missing pkg-config templates
  * Remove autoconf installed files from git control
  * Fix get_supported_flags() arguments
  * Properly detect 64-bit architecture.
  * Add -f argument to autoreconf to regenerate aclocal macros
  * Silent autoconf warning for ac_cv_sizeof_long
  * Fix C++ build issues (add missing cplusplus macros definitions)
  * Make liberasurecode header installs to a specific include directory
  * Fix 'make test' to properly run null and installed backend tests.
  * Fix a uint < 0 warning reported by Clang
  * Fix memory leak in alg_sig init
  * Fix decode when m > k and all parities are chosen as input to decode
- run tests
* Thu Jul 23 2015 dmueller@suse.com
- Initial package (1.0.7)
